/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.odf.web');

/**
 * Creates the control. There is one instance per control. Extends this method to initialize your component.
 * @param {String} id The unique button identifier
 * @param {Map<id, value>} configuration The configuration of the control instance.
 * @param {String} The name of the plugin where the control was declared
 * @class This interface is used for ribbon control. You must implement it to creates a control.
 * @constructor
 */
org.ametys.odf.web.DeleteProgramListener = function()
{
	org.ametys.messagebus.MessageBus.getInstance().register(this);
}

org.ametys.odf.web.DeleteProgramListener.prototype.onMessage = function (messages)
{
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_DELETED || messages[i].getType().getName() == 'archived')
		{
			var targets = messages[i].getTargets();
			var contentTarget = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this._checkTarget.createDelegate(this));
			
			if (contentTarget != null)
			{
				var params = {'siteName': context.parameters.siteName, 'lang': org.ametys.web.helper.LanguageHelper.getCurrentLanguage()};
				var serverMessage = new org.ametys.servercomm.ServerMessage('odf-web', '/get-odf-root', params, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
				var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
				
				if (response != null || response.getAttribute("code") == "200")
				{
					var rootPages = response.selectNodes("odf-root-pages/page");
					var rootPageIds = [];
					for (var i=0; i < rootPages.length; i++)
					{
						rootPageIds.push(rootPages[i].getAttribute('id'));
					}

					if (rootPageIds.length > 0)
					{
						var pageTargets = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTargets("page", {'ids': rootPageIds});
						var event = org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage('needReload', null, [pageTargets]);
						org.ametys.messagebus.MessageBus.getInstance().fireMessages([event]);
					}
				}
			}
		}
	}
}

org.ametys.odf.web.DeleteProgramListener.prototype._checkTarget = function (target)
{
	return target.getType() == "content" && (target.getParameters().type == 'org.ametys.plugins.odf.Content.program' || target.getParameters().type == 'org.ametys.plugins.odf.Content.subProgram');
}

// Create listener
new org.ametys.odf.web.DeleteProgramListener ();
